export = MockRequestsWebpackPlugin;
/**
 * Webpack plugin for automatically resolving the mock directory,
 * including transpiling all files it contains as well as adding
 * the entry file within it to the build/run output for the user.
 *
 * @extends WebpackPluginInstance
 */
declare class MockRequestsWebpackPlugin {
    /**
     * Activates mock-requests based on the provided parameters.
     *
     * @param {string} mocksDir - Directory of all mock files/logic, including the `mockEntryFile`.
     * @param {string} mockEntryFile - Entry file that calls `MockRequests.configure()`.
     * @param {boolean} activateMocks - If mocks determined by `mockEntryFile` should be activated or not.
     * @param {Object} [options]
     * @param {boolean} [options.pathsAreAbsolute=false] - If `mocksDir` and `mockEntryFile` are absolute paths instead of relative.
     * @param {boolean} [options.transpileMocksDir=true] - If the files within `mocksDir` should be transpiled.
     */
    constructor(mocksDir: string, mockEntryFile: string, activateMocks: boolean, { pathsAreAbsolute, transpileMocksDir }?: {
        pathsAreAbsolute?: boolean;
        transpileMocksDir?: boolean;
    });
    mocksDir: string;
    mockEntryFile: string;
    activateMocks: boolean;
    pathsAreAbsolute: boolean;
    transpileMocksDir: boolean;
    get pluginName(): string;
    getAbsPath(projectRootPath: any, includeEntryFile?: boolean): string;
    setAbsPaths(projectRootPath: any): void;
    mockDirAbsPath: string;
    mockEntryAbsPath: string;
    /**
     * @param {RuleSetCondition} condition - User-defined condition for matching directories/files.
     * @returns {boolean} - If the condition matches the mock directory/entry file.
     * @private
     */
    private webpackConditionMatchesMockDir;
    injectMocksIntoWebpackConfig(projectRootPath: any, moduleRules: any, entry: any): void;
    addMockEntryFileToConfigEntry(configEntryList: any): boolean;
    addMockDirToModuleRule(moduleRules: any): void;
    /**
     * @param {Compiler} compiler
     * @private
     */
    private apply;
}
declare namespace MockRequestsWebpackPlugin {
    export { MockRequestsWebpackPlugin as default };
}
